@@ -131,18 +131,24 @@ def predecir_clasificacion_binaria(model, X=None, umbral=0.5):
 
 
 def get_result_df(KPIs_list):
-    df = pd.DataFrame(columns=["Macro Región","Modelo","T Train","T Test",'Precision', 'Recall', 'F1','Average Precision','ROC AUC',"umbral_opt",'Precision_opt', 'Recall_opt', 'F1_opt','Average Precision opt','ROC AUC opt'])
+    df = pd.DataFrame(columns=["Macro Región","Modelo","T Train","T Train Class 1","T Test","T Test Class 1",'Precision', 'Recall', 'F1','Average Precision','ROC AUC',"umbral_opt",'Precision_opt', 'Recall_opt', 'F1_opt','Average Precision opt','ROC AUC opt'])
     for idx, result  in enumerate(KPIs_list):
         mr = result[0]
+        
         mod = result[1]
         
         t_train = result[2]
-        t_test = result[3]
         
-        Ks = result[4]
-        umbral_opt = result[5]
-        Ks_opt = result[6]
-        result_rd = [mr,mod,t_train,t_test]+[round(num, 3) for num in list(Ks)]+[umbral_opt]+[round(num_opt, 3) for num_opt in list(Ks_opt)]
+        t_train_class_1 = result[3]
+        
+        t_test = result[4]
+        
+        t_test_class_1 = result[5]
+        
+        Ks = result[6]
+        umbral_opt = result[7]
+        Ks_opt = result[8]
+        result_rd = [mr,mod,t_train,t_train_class_1,t_test,t_test_class_1]+[round(num, 3) for num in list(Ks)]+[umbral_opt]+[round(num_opt, 3) for num_opt in list(Ks_opt)]
         df.loc[idx] = result_rd
 
         #df.loc[i] = list(KPIs)
